@@ -365,7 +365,7 @@ impl OIDMask {
         }
     }
     #[inline]
-    pub fn to_path(&self) -> String {
+    pub fn as_path(&self) -> String {
         if self.path.chunks.is_some() {
             format!(
                 "{}/{}",
@@ -740,14 +740,14 @@ mod tests {
         let mask: OIDMask = s.parse().unwrap();
         assert_eq!(s, mask.to_string());
         assert_eq!(mask.path.chunks, None);
-        assert_eq!(mask.to_path(), "#");
+        assert_eq!(mask.as_path(), "#");
         let s = "";
         assert_eq!(s.parse::<OIDMask>().is_err(), true);
         let s = "sensor:";
         assert_eq!(s.parse::<OIDMask>().is_err(), true);
         let s = "sensor:data/#";
         let mask: OIDMask = s.parse().unwrap();
-        assert_eq!(mask.to_path(), "sensor/data/#");
+        assert_eq!(mask.as_path(), "sensor/data/#");
         assert_eq!(s, mask.to_string());
         assert_eq!(mask.kind.unwrap(), ItemKind::Sensor);
         assert_eq!(mask.path.chunks.unwrap(), ["data", "#"]);
@@ -755,7 +755,7 @@ mod tests {
         assert_eq!(s.parse::<OIDMask>().is_err(), true);
         let s = "+:data/tests/t1";
         let mask: OIDMask = s.parse().unwrap();
-        assert_eq!(mask.to_path(), "+/data/tests/t1");
+        assert_eq!(mask.as_path(), "+/data/tests/t1");
         assert_eq!(s, mask.to_string());
         assert_eq!(mask.path.chunks.unwrap(), ["data", "tests", "t1"]);
         assert_eq!(mask.kind, None);
