@@ -1,3 +1,4 @@
+use crate::payload::{pack, unpack};
 use crate::{EResult, Error};
 use log::{error, trace};
 use serde::{de::DeserializeOwned, Serialize};
@@ -94,7 +95,7 @@ impl TtlCache {
         }
         sqlx::query("INSERT OR REPLACE INTO kv (k, v, t) VALUES (?, ?, ?)")
             .bind(key)
-            .bind(rmp_serde::to_vec_named(value)?)
+            .bind(pack(value)?)
             .bind(now().as_secs() as i64)
             .execute(&self.pool)
             .await?;
@@ -108,7 +109,7 @@ impl TtlCache {
             .fetch_optional(&self.pool)
             .await?;
         if let Some(v) = val {
-            Ok(Some(rmp_serde::from_slice(&v.0)?))
+            Ok(Some(unpack(&v.0)?))
         } else {
             Ok(None)
         }
