@@ -48,6 +48,8 @@ pub mod services;
 pub mod time;
 #[cfg(feature = "workers")]
 pub mod workers;
+#[cfg(feature = "payload")]
+pub mod payload;
 
 pub mod value;
 
@@ -265,17 +267,11 @@ impl_err_error!(tokio::sync::oneshot::error::RecvError, Error::io);
 #[cfg(any(feature = "services", feature = "workers"))]
 impl_err_error!(tokio::sync::TryLockError, Error::core);
 #[cfg(any(
-    feature = "elbus-rpc",
-    feature = "registry",
-    feature = "ext",
-    feature = "cache"
+    feature = "payload",
 ))]
 impl_err_error!(rmp_serde::encode::Error, Error::invalid_data);
 #[cfg(any(
-    feature = "elbus-rpc",
-    feature = "registry",
-    feature = "ext",
-    feature = "cache"
+    feature = "payload",
 ))]
 impl_err_error!(rmp_serde::decode::Error, Error::invalid_data);
 impl_err_error!(std::array::TryFromSliceError, Error::invalid_data);
@@ -720,7 +716,7 @@ impl OID {
         self.kind
     }
     #[inline]
-    pub fn to_path(&self) -> String {
+    pub fn as_path(&self) -> String {
         format!("{}/{}", self.kind, self.full_id())
     }
     #[inline]
