@@ -54,15 +54,14 @@ impl Default for ValueOptionOwned {
 }
 
 impl ValueOptionOwned {
-    #[inline]
     pub fn is_none(&self) -> bool {
         matches!(self, ValueOptionOwned::No)
     }
-    #[inline]
+
     pub fn is_some(&self) -> bool {
         !matches!(self, ValueOptionOwned::No)
     }
-    #[inline]
+
     pub fn as_ref(&self) -> Option<&Value> {
         match self {
             ValueOptionOwned::No => None,
@@ -105,11 +104,10 @@ impl<'a> Default for ValueOption<'a> {
 }
 
 impl<'a> ValueOption<'a> {
-    #[inline]
     pub fn is_none(&self) -> bool {
         matches!(self, ValueOption::No)
     }
-    #[inline]
+
     pub fn is_some(&self) -> bool {
         !matches!(self, ValueOption::No)
     }
@@ -153,7 +151,6 @@ pub enum Value {
 }
 
 impl Default for Value {
-    #[inline]
     fn default() -> Self {
         Value::Unit
     }
@@ -296,7 +293,7 @@ impl Value {
     /// Rounds value to digits after comma, if the value is float
     #[allow(clippy::cast_possible_truncation)]
     #[allow(clippy::cast_sign_loss)]
-    #[inline]
+
     pub fn rounded(self, precision: Option<u32>) -> EResult<Value> {
         if let Some(precs) = precision {
             if let Value::F64(vf) = self {
@@ -329,7 +326,6 @@ impl Value {
         Ok(self)
     }
 
-    #[inline]
     pub fn to_no_bytes(self) -> Value {
         strip_bytes_rec(self)
     }
@@ -596,80 +592,69 @@ impl_from!(f32, Value::F32);
 impl_from!(f64, Value::F64);
 impl_from!(String, Value::String);
 
-impl TryFrom<&Value> for f64 {
-    type Error = Error;
-    #[inline]
-    fn try_from(value: &Value) -> EResult<f64> {
-        macro_rules! ngt {
-            ($n: expr, $x: ty) => {
-                if $n > std::f64::MAX as $x {
-                    return Err(Error::invalid_data(format!(
-                        "Value too big: {} (max: {}",
-                        $n,
-                        std::f64::MAX
-                    )));
-                } else if $n < std::f64::MIN as $x {
-                    return Err(Error::invalid_data(format!(
-                        "Value too small: {} (min: {}",
-                        $n,
-                        std::f64::MIN
-                    )));
-                } else {
-                    $n as f64
-                }
-            };
+// comparing $from unsigned bigger
+macro_rules! ngt {
+    ($n: expr, $from: ident, $to: ident) => {
+        if $n > $to::MAX as $from {
+            return Err(Error::invalid_data(format!(
+                "value too big: {} (max: {})",
+                $n,
+                $to::MAX
+            )));
+        } else {
+            $n as $to
         }
-        match value {
-            Value::F32(v) => Ok(f64::from(*v)),
-            Value::F64(v) => Ok(*v),
-            Value::U8(v) => Ok(f64::from(*v)),
-            Value::U16(v) => Ok(f64::from(*v)),
-            Value::U32(v) => Ok(f64::from(*v)),
-            Value::U64(v) => Ok(ngt!(*v, u64)),
-            Value::I8(v) => Ok(f64::from(*v)),
-            Value::I16(v) => Ok(f64::from(*v)),
-            Value::I32(v) => Ok(f64::from(*v)),
-            Value::I64(v) => Ok(ngt!(*v, i64)),
-            Value::String(v) => Ok(v.parse::<f64>()?),
-            _ => Err(Error::invalid_data(ERR_INVALID_VALUE)),
+    };
+}
+// comparing $from signed bigger $to signed/unsigned smaller
+macro_rules! ngt_nlt {
+    ($n: expr, $from: ident, $to: ident) => {
+        if $n > $to::MAX as $from {
+            return Err(Error::invalid_data(format!(
+                "value too big: {} (max: {})",
+                $n,
+                $to::MAX
+            )));
+        } else if $n < $to::MIN as $from {
+            return Err(Error::invalid_data(format!(
+                "value too small: {} (min: {})",
+                $n,
+                $to::MIN
+            )));
+        } else {
+            $n as $to
         }
-    }
+    };
+}
+// comparing $from smaller signed with $to unsigned (check that $from is zero-positive)
+macro_rules! nltz {
+    ($n: expr, $from: ident, $to: ident) => {
+        if $n < 0 as $from {
+            return Err(Error::invalid_data(format!(
+                "value too small: {} (min: 0)",
+                $n,
+            )));
+        } else {
+            $n as $to
+        }
+    };
 }
 
 impl TryFrom<Value> for u8 {
     type Error = Error;
-    #[inline]
+
     fn try_from(value: Value) -> EResult<u8> {
-        macro_rules! ngt {
-            ($n: expr, $x: ty) => {
-                if $n > std::u8::MAX as $x {
-                    return Err(Error::invalid_data(format!(
-                        "Value too big: {} (max: {}",
-                        $n,
-                        std::u8::MAX
-                    )));
-                } else if $n < std::u8::MIN as $x {
-                    return Err(Error::invalid_data(format!(
-                        "Value too small: {} (min: {}",
-                        $n,
-                        std::u8::MIN
-                    )));
-                } else {
-                    $n as u8
-                }
-            };
-        }
         match value {
-            Value::F32(v) => Ok(ngt!(v, f32)),
-            Value::F64(v) => Ok(ngt!(v, f64)),
             Value::U8(v) => Ok(v),
-            Value::U16(v) => Ok(ngt!(v, u16)),
-            Value::U32(v) => Ok(ngt!(v, u32)),
-            Value::U64(v) => Ok(ngt!(v, u64)),
-            Value::I8(v) => Ok(ngt!(v, i8)),
-            Value::I16(v) => Ok(ngt!(v, i16)),
-            Value::I32(v) => Ok(ngt!(v, i32)),
-            Value::I64(v) => Ok(ngt!(v, i64)),
+            Value::U16(v) => Ok(ngt!(v, u16, u8)),
+            Value::U32(v) => Ok(ngt!(v, u32, u8)),
+            Value::U64(v) => Ok(ngt!(v, u64, u8)),
+            Value::I8(v) => Ok(nltz!(v, i8, u8)),
+            Value::I16(v) => Ok(ngt_nlt!(v, i16, u8)),
+            Value::I32(v) => Ok(ngt_nlt!(v, i32, u8)),
+            Value::I64(v) => Ok(ngt_nlt!(v, i64, u8)),
+            Value::F32(v) => Ok(ngt_nlt!(v, f32, u8)),
+            Value::F64(v) => Ok(ngt_nlt!(v, f64, u8)),
             Value::String(v) => Ok(v.parse::<u8>()?),
             _ => Err(Error::invalid_data(ERR_INVALID_VALUE)),
         }
@@ -678,38 +663,19 @@ impl TryFrom<Value> for u8 {
 
 impl TryFrom<Value> for i8 {
     type Error = Error;
-    #[inline]
+
     fn try_from(value: Value) -> EResult<i8> {
-        macro_rules! ngt {
-            ($n: expr, $x: ty) => {
-                if $n > std::i8::MAX as $x {
-                    return Err(Error::invalid_data(format!(
-                        "Value too big: {} (max: {}",
-                        $n,
-                        std::i8::MAX
-                    )));
-                } else if $n < std::i8::MIN as $x {
-                    return Err(Error::invalid_data(format!(
-                        "Value too small: {} (min: {}",
-                        $n,
-                        std::i8::MIN
-                    )));
-                } else {
-                    $n as i8
-                }
-            };
-        }
         match value {
-            Value::F32(v) => Ok(ngt!(v, f32)),
-            Value::F64(v) => Ok(ngt!(v, f64)),
-            Value::U8(v) => Ok(ngt!(v, u8)),
-            Value::U16(v) => Ok(ngt!(v, u16)),
-            Value::U32(v) => Ok(ngt!(v, u32)),
-            Value::U64(v) => Ok(ngt!(v, u64)),
+            Value::U8(v) => Ok(ngt!(v, u8, i8)),
+            Value::U16(v) => Ok(ngt!(v, u16, i8)),
+            Value::U32(v) => Ok(ngt!(v, u32, i8)),
+            Value::U64(v) => Ok(ngt!(v, u64, i8)),
             Value::I8(v) => Ok(v),
-            Value::I16(v) => Ok(ngt!(v, i16)),
-            Value::I32(v) => Ok(ngt!(v, i32)),
-            Value::I64(v) => Ok(ngt!(v, i64)),
+            Value::I16(v) => Ok(ngt_nlt!(v, i16, i8)),
+            Value::I32(v) => Ok(ngt_nlt!(v, i32, i8)),
+            Value::I64(v) => Ok(ngt_nlt!(v, i64, i8)),
+            Value::F32(v) => Ok(ngt_nlt!(v, f32, i8)),
+            Value::F64(v) => Ok(ngt_nlt!(v, f64, i8)),
             Value::String(v) => Ok(v.parse::<i8>()?),
             _ => Err(Error::invalid_data(ERR_INVALID_VALUE)),
         }
@@ -718,38 +684,19 @@ impl TryFrom<Value> for i8 {
 
 impl TryFrom<Value> for u16 {
     type Error = Error;
-    #[inline]
+
     fn try_from(value: Value) -> EResult<u16> {
-        macro_rules! ngt {
-            ($n: expr, $x: ty) => {
-                if $n > std::u16::MAX as $x {
-                    return Err(Error::invalid_data(format!(
-                        "Value too big: {} (max: {}",
-                        $n,
-                        std::u16::MAX
-                    )));
-                } else if $n < std::u16::MIN as $x {
-                    return Err(Error::invalid_data(format!(
-                        "Value too small: {} (min: {}",
-                        $n,
-                        std::u16::MIN
-                    )));
-                } else {
-                    $n as u16
-                }
-            };
-        }
         match value {
-            Value::F32(v) => Ok(ngt!(v, f32)),
-            Value::F64(v) => Ok(ngt!(v, f64)),
             Value::U8(v) => Ok(u16::from(v)),
             Value::U16(v) => Ok(v),
-            Value::U32(v) => Ok(ngt!(v, u32)),
-            Value::U64(v) => Ok(ngt!(v, u64)),
-            Value::I8(v) => Ok(ngt!(v, i8)),
-            Value::I16(v) => Ok(ngt!(v, i16)),
-            Value::I32(v) => Ok(ngt!(v, i32)),
-            Value::I64(v) => Ok(ngt!(v, i64)),
+            Value::U32(v) => Ok(ngt!(v, u32, u16)),
+            Value::U64(v) => Ok(ngt!(v, u64, u16)),
+            Value::I8(v) => Ok(nltz!(v, i8, u16)),
+            Value::I16(v) => Ok(nltz!(v, i16, u16)),
+            Value::I32(v) => Ok(ngt_nlt!(v, i32, u16)),
+            Value::I64(v) => Ok(ngt_nlt!(v, i64, u16)),
+            Value::F32(v) => Ok(ngt_nlt!(v, f32, u16)),
+            Value::F64(v) => Ok(ngt_nlt!(v, f64, u16)),
             Value::String(v) => Ok(v.parse::<u16>()?),
             _ => Err(Error::invalid_data(ERR_INVALID_VALUE)),
         }
@@ -758,38 +705,19 @@ impl TryFrom<Value> for u16 {
 
 impl TryFrom<Value> for i16 {
     type Error = Error;
-    #[inline]
+
     fn try_from(value: Value) -> EResult<i16> {
-        macro_rules! ngt {
-            ($n: expr, $x: ty) => {
-                if $n > std::i16::MAX as $x {
-                    return Err(Error::invalid_data(format!(
-                        "Value too big: {} (max: {}",
-                        $n,
-                        std::i16::MAX
-                    )));
-                } else if $n < std::i16::MIN as $x {
-                    return Err(Error::invalid_data(format!(
-                        "Value too small: {} (min: {}",
-                        $n,
-                        std::i16::MIN
-                    )));
-                } else {
-                    $n as i16
-                }
-            };
-        }
         match value {
-            Value::F32(v) => Ok(ngt!(v, f32)),
-            Value::F64(v) => Ok(ngt!(v, f64)),
             Value::U8(v) => Ok(i16::from(v)),
-            Value::U16(v) => Ok(ngt!(v, u16)),
-            Value::U32(v) => Ok(ngt!(v, u32)),
-            Value::U64(v) => Ok(ngt!(v, u64)),
+            Value::U16(v) => Ok(ngt!(v, u16, i16)),
+            Value::U32(v) => Ok(ngt!(v, u32, i16)),
+            Value::U64(v) => Ok(ngt!(v, u64, i16)),
             Value::I8(v) => Ok(i16::from(v)),
             Value::I16(v) => Ok(v),
-            Value::I32(v) => Ok(ngt!(v, i32)),
-            Value::I64(v) => Ok(ngt!(v, i64)),
+            Value::I32(v) => Ok(ngt_nlt!(v, i32, i16)),
+            Value::I64(v) => Ok(ngt_nlt!(v, i64, i16)),
+            Value::F32(v) => Ok(ngt_nlt!(v, f32, i16)),
+            Value::F64(v) => Ok(ngt_nlt!(v, f64, i16)),
             Value::String(v) => Ok(v.parse::<i16>()?),
             _ => Err(Error::invalid_data(ERR_INVALID_VALUE)),
         }
@@ -798,38 +726,19 @@ impl TryFrom<Value> for i16 {
 
 impl TryFrom<Value> for u32 {
     type Error = Error;
-    #[inline]
+
     fn try_from(value: Value) -> EResult<u32> {
-        macro_rules! ngt {
-            ($n: expr, $x: ty) => {
-                if $n > std::u32::MAX as $x {
-                    return Err(Error::invalid_data(format!(
-                        "Value too big: {} (max: {}",
-                        $n,
-                        std::u32::MAX
-                    )));
-                } else if $n < std::u32::MIN as $x {
-                    return Err(Error::invalid_data(format!(
-                        "Value too small: {} (min: {}",
-                        $n,
-                        std::u32::MIN
-                    )));
-                } else {
-                    $n as u32
-                }
-            };
-        }
         match value {
-            Value::F32(v) => Ok(ngt!(v, f32)),
-            Value::F64(v) => Ok(ngt!(v, f64)),
             Value::U8(v) => Ok(u32::from(v)),
             Value::U16(v) => Ok(u32::from(v)),
             Value::U32(v) => Ok(v),
-            Value::U64(v) => Ok(ngt!(v, u64)),
-            Value::I8(v) => Ok(ngt!(v, i8)),
-            Value::I16(v) => Ok(ngt!(v, i16)),
-            Value::I32(v) => Ok(ngt!(v, i32)),
-            Value::I64(v) => Ok(ngt!(v, i64)),
+            Value::U64(v) => Ok(ngt!(v, u64, u32)),
+            Value::I8(v) => Ok(nltz!(v, i8, u32)),
+            Value::I16(v) => Ok(nltz!(v, i16, u32)),
+            Value::I32(v) => Ok(nltz!(v, i32, u32)),
+            Value::I64(v) => Ok(ngt_nlt!(v, i64, u32)),
+            Value::F32(v) => Ok(nltz!(v, f32, u32)),
+            Value::F64(v) => Ok(ngt_nlt!(v, f64, u32)),
             Value::String(v) => Ok(v.parse::<u32>()?),
             _ => Err(Error::invalid_data(ERR_INVALID_VALUE)),
         }
@@ -838,38 +747,20 @@ impl TryFrom<Value> for u32 {
 
 impl TryFrom<Value> for i32 {
     type Error = Error;
-    #[inline]
+
     fn try_from(value: Value) -> EResult<i32> {
-        macro_rules! ngt {
-            ($n: expr, $x: ty) => {
-                if $n > std::i32::MAX as $x {
-                    return Err(Error::invalid_data(format!(
-                        "Value too big: {} (max: {}",
-                        $n,
-                        std::i32::MAX
-                    )));
-                } else if $n < std::i32::MIN as $x {
-                    return Err(Error::invalid_data(format!(
-                        "Value too small: {} (min: {}",
-                        $n,
-                        std::i32::MIN
-                    )));
-                } else {
-                    $n as i32
-                }
-            };
-        }
         match value {
-            Value::F32(v) => Ok(ngt!(v, f32)),
-            Value::F64(v) => Ok(ngt!(v, f64)),
             Value::U8(v) => Ok(i32::from(v)),
             Value::U16(v) => Ok(i32::from(v)),
-            Value::U32(v) => Ok(ngt!(v, u32)),
-            Value::U64(v) => Ok(ngt!(v, u64)),
+            Value::U32(v) => Ok(ngt!(v, u32, i32)),
+            Value::U64(v) => Ok(ngt!(v, u64, i32)),
             Value::I8(v) => Ok(i32::from(v)),
             Value::I16(v) => Ok(i32::from(v)),
             Value::I32(v) => Ok(v),
-            Value::I64(v) => Ok(ngt!(v, i64)),
+            Value::I64(v) => Ok(ngt_nlt!(v, i64, i32)),
+            #[allow(clippy::cast_possible_truncation)]
+            Value::F32(v) => Ok(v as i32),
+            Value::F64(v) => Ok(ngt_nlt!(v, f64, i32)),
             Value::String(v) => Ok(v.parse::<i32>()?),
             _ => Err(Error::invalid_data(ERR_INVALID_VALUE)),
         }
@@ -878,38 +769,19 @@ impl TryFrom<Value> for i32 {
 
 impl TryFrom<&Value> for u64 {
     type Error = Error;
-    #[inline]
+
     fn try_from(value: &Value) -> EResult<u64> {
-        macro_rules! ngt {
-            ($n: expr, $x: ty) => {
-                if $n > std::u64::MAX as $x {
-                    return Err(Error::invalid_data(format!(
-                        "Value too big: {} (max: {}",
-                        $n,
-                        std::u64::MAX
-                    )));
-                } else if $n < std::u64::MIN as $x {
-                    return Err(Error::invalid_data(format!(
-                        "Value too small: {} (min: {}",
-                        $n,
-                        std::u64::MIN
-                    )));
-                } else {
-                    $n as u64
-                }
-            };
-        }
         match value {
-            Value::F32(v) => Ok(ngt!(*v, f32)),
-            Value::F64(v) => Ok(ngt!(*v, f64)),
             Value::U8(v) => Ok(u64::from(*v)),
             Value::U16(v) => Ok(u64::from(*v)),
             Value::U32(v) => Ok(u64::from(*v)),
-            Value::U64(v) => Ok(*v as u64),
-            Value::I8(v) => Ok(ngt!(*v, i8)),
-            Value::I16(v) => Ok(ngt!(*v, i16)),
-            Value::I32(v) => Ok(ngt!(*v, i32)),
-            Value::I64(v) => Ok(ngt!(*v, i64)),
+            Value::U64(v) => Ok(*v),
+            Value::I8(v) => Ok(nltz!(*v, i8, u64)),
+            Value::I16(v) => Ok(nltz!(*v, i16, u64)),
+            Value::I32(v) => Ok(nltz!(*v, i32, u64)),
+            Value::I64(v) => Ok(nltz!(*v, i64, u64)),
+            Value::F32(v) => Ok(nltz!(*v, f32, u64)),
+            Value::F64(v) => Ok(nltz!(*v, f64, u64)),
             Value::String(v) => Ok(v.parse::<u64>()?),
             _ => Err(Error::invalid_data(ERR_INVALID_VALUE)),
         }
@@ -918,38 +790,19 @@ impl TryFrom<&Value> for u64 {
 
 impl TryFrom<Value> for u64 {
     type Error = Error;
-    #[inline]
+
     fn try_from(value: Value) -> EResult<u64> {
-        macro_rules! ngt {
-            ($n: expr, $x: ty) => {
-                if $n > std::u64::MAX as $x {
-                    return Err(Error::invalid_data(format!(
-                        "Value too big: {} (max: {}",
-                        $n,
-                        std::u64::MAX
-                    )));
-                } else if $n < std::u64::MIN as $x {
-                    return Err(Error::invalid_data(format!(
-                        "Value too small: {} (min: {}",
-                        $n,
-                        std::u64::MIN
-                    )));
-                } else {
-                    $n as u64
-                }
-            };
-        }
         match value {
-            Value::F32(v) => Ok(ngt!(v, f32)),
-            Value::F64(v) => Ok(ngt!(v, f64)),
             Value::U8(v) => Ok(u64::from(v)),
             Value::U16(v) => Ok(u64::from(v)),
             Value::U32(v) => Ok(u64::from(v)),
-            Value::U64(v) => Ok(v as u64),
-            Value::I8(v) => Ok(ngt!(v, i8)),
-            Value::I16(v) => Ok(ngt!(v, i16)),
-            Value::I32(v) => Ok(ngt!(v, i32)),
-            Value::I64(v) => Ok(ngt!(v, i64)),
+            Value::U64(v) => Ok(v),
+            Value::I8(v) => Ok(nltz!(v, i8, u64)),
+            Value::I16(v) => Ok(nltz!(v, i16, u64)),
+            Value::I32(v) => Ok(nltz!(v, i32, u64)),
+            Value::I64(v) => Ok(nltz!(v, i64, u64)),
+            Value::F32(v) => Ok(nltz!(v, f32, u64)),
+            Value::F64(v) => Ok(nltz!(v, f64, u64)),
             Value::String(v) => Ok(v.parse::<u64>()?),
             _ => Err(Error::invalid_data(ERR_INVALID_VALUE)),
         }
@@ -958,40 +811,21 @@ impl TryFrom<Value> for u64 {
 
 impl TryFrom<&Value> for i64 {
     type Error = Error;
-    #[inline]
+
     fn try_from(value: &Value) -> EResult<i64> {
-        macro_rules! ngt {
-            ($n: expr, $x: ty) => {
-                if $n > std::i64::MAX as $x {
-                    return Err(Error::invalid_data(format!(
-                        "Value too big: {} (max: {}",
-                        $n,
-                        std::i64::MAX
-                    )));
-                } else if $n < std::i64::MIN as $x {
-                    return Err(Error::invalid_data(format!(
-                        "Value too small: {} (min: {}",
-                        $n,
-                        std::i64::MIN
-                    )));
-                } else {
-                    $n as i64
-                }
-            };
-        }
         match value {
-            #[allow(clippy::cast_possible_truncation)]
-            Value::F32(v) => Ok(*v as i64),
-            #[allow(clippy::cast_possible_truncation)]
-            Value::F64(v) => Ok(*v as i64),
             Value::U8(v) => Ok(i64::from(*v)),
             Value::U16(v) => Ok(i64::from(*v)),
             Value::U32(v) => Ok(i64::from(*v)),
-            Value::U64(v) => Ok(ngt!(*v, u64)),
+            Value::U64(v) => Ok(ngt!(*v, u64, i64)),
             Value::I8(v) => Ok(i64::from(*v)),
             Value::I16(v) => Ok(i64::from(*v)),
             Value::I32(v) => Ok(i64::from(*v)),
             Value::I64(v) => Ok(*v),
+            #[allow(clippy::cast_possible_truncation)]
+            Value::F32(v) => Ok(*v as i64),
+            #[allow(clippy::cast_possible_truncation)]
+            Value::F64(v) => Ok(*v as i64),
             Value::String(v) => Ok(v.parse::<i64>()?),
             _ => Err(Error::invalid_data(ERR_INVALID_VALUE)),
         }
@@ -1000,40 +834,21 @@ impl TryFrom<&Value> for i64 {
 
 impl TryFrom<Value> for i64 {
     type Error = Error;
-    #[inline]
+
     fn try_from(value: Value) -> EResult<i64> {
-        macro_rules! ngt {
-            ($n: expr, $x: ty) => {
-                if $n > std::i64::MAX as $x {
-                    return Err(Error::invalid_data(format!(
-                        "Value too big: {} (max: {}",
-                        $n,
-                        std::i64::MAX
-                    )));
-                } else if $n < std::i64::MIN as $x {
-                    return Err(Error::invalid_data(format!(
-                        "Value too small: {} (min: {}",
-                        $n,
-                        std::i64::MIN
-                    )));
-                } else {
-                    $n as i64
-                }
-            };
-        }
         match value {
-            #[allow(clippy::cast_possible_truncation)]
-            Value::F32(v) => Ok(v as i64),
-            #[allow(clippy::cast_possible_truncation)]
-            Value::F64(v) => Ok(v as i64),
             Value::U8(v) => Ok(i64::from(v)),
             Value::U16(v) => Ok(i64::from(v)),
             Value::U32(v) => Ok(i64::from(v)),
-            Value::U64(v) => Ok(ngt!(v, u64)),
+            Value::U64(v) => Ok(ngt!(v, u64, i64)),
             Value::I8(v) => Ok(i64::from(v)),
             Value::I16(v) => Ok(i64::from(v)),
             Value::I32(v) => Ok(i64::from(v)),
             Value::I64(v) => Ok(v),
+            #[allow(clippy::cast_possible_truncation)]
+            Value::F32(v) => Ok(v as i64),
+            #[allow(clippy::cast_possible_truncation)]
+            Value::F64(v) => Ok(v as i64),
             Value::String(v) => Ok(v.parse::<i64>()?),
             _ => Err(Error::invalid_data(ERR_INVALID_VALUE)),
         }
@@ -1042,78 +857,61 @@ impl TryFrom<Value> for i64 {
 
 impl TryFrom<Value> for f32 {
     type Error = Error;
-    #[inline]
+
     fn try_from(value: Value) -> EResult<f32> {
-        macro_rules! ngt {
-            ($n: expr, $x: ty) => {
-                if $n > std::f32::MAX as $x {
-                    return Err(Error::invalid_data(format!(
-                        "Value too big: {} (max: {}",
-                        $n,
-                        std::f32::MAX
-                    )));
-                } else if $n < std::f32::MIN as $x {
-                    return Err(Error::invalid_data(format!(
-                        "Value too small: {} (min: {}",
-                        $n,
-                        std::f32::MIN
-                    )));
-                } else {
-                    $n as f32
-                }
-            };
-        }
         match value {
             Value::F32(v) => Ok(v),
-            Value::F64(v) => Ok(ngt!(v, f64)),
+            Value::F64(v) => Ok(ngt_nlt!(v, f64, f32)),
             Value::U8(v) => Ok(f32::from(v)),
             Value::U16(v) => Ok(f32::from(v)),
-            Value::U32(v) => Ok(ngt!(v, u32)),
-            Value::U64(v) => Ok(ngt!(v, u64)),
-            Value::I8(v) => Ok(ngt!(v, i8)),
-            Value::I16(v) => Ok(ngt!(v, i16)),
-            Value::I32(v) => Ok(ngt!(v, i32)),
-            Value::I64(v) => Ok(ngt!(v, i64)),
+            Value::U32(v) => Ok(ngt!(v, u32, f32)),
+            Value::U64(v) => Ok(ngt!(v, u64, f32)),
+            Value::I8(v) => Ok(f32::from(v)),
+            Value::I16(v) => Ok(f32::from(v)),
+            Value::I32(v) => Ok(ngt_nlt!(v, i32, f32)),
+            Value::I64(v) => Ok(ngt_nlt!(v, i64, f32)),
             Value::String(v) => Ok(v.parse::<f32>()?),
             _ => Err(Error::invalid_data(ERR_INVALID_VALUE)),
         }
     }
 }
 
+impl TryFrom<&Value> for f64 {
+    type Error = Error;
+
+    fn try_from(value: &Value) -> EResult<f64> {
+        match value {
+            Value::U8(v) => Ok(f64::from(*v)),
+            Value::U16(v) => Ok(f64::from(*v)),
+            Value::U32(v) => Ok(f64::from(*v)),
+            Value::U64(v) => Ok(ngt!(*v, u64, f64)),
+            Value::I8(v) => Ok(f64::from(*v)),
+            Value::I16(v) => Ok(f64::from(*v)),
+            Value::I32(v) => Ok(f64::from(*v)),
+            Value::I64(v) => Ok(ngt_nlt!(*v, i64, f64)),
+            Value::F32(v) => Ok(f64::from(*v)),
+            Value::F64(v) => Ok(*v),
+            Value::String(v) => Ok(v.parse::<f64>()?),
+            _ => Err(Error::invalid_data(ERR_INVALID_VALUE)),
+        }
+    }
+}
+
 impl TryFrom<Value> for f64 {
     type Error = Error;
-    #[inline]
+
     fn try_from(value: Value) -> EResult<f64> {
-        macro_rules! ngt {
-            ($n: expr, $x: ty) => {
-                if $n > std::f64::MAX as $x {
-                    return Err(Error::invalid_data(format!(
-                        "Value too big: {} (max: {}",
-                        $n,
-                        std::f64::MAX
-                    )));
-                } else if $n < std::f64::MIN as $x {
-                    return Err(Error::invalid_data(format!(
-                        "Value too small: {} (min: {}",
-                        $n,
-                        std::f64::MIN
-                    )));
-                } else {
-                    $n as f64
-                }
-            };
-        }
         match value {
-            Value::F32(v) => Ok(f64::from(v)),
-            Value::F64(v) => Ok(v),
             Value::U8(v) => Ok(f64::from(v)),
             Value::U16(v) => Ok(f64::from(v)),
             Value::U32(v) => Ok(f64::from(v)),
-            Value::U64(v) => Ok(ngt!(v, u64)),
+            Value::U64(v) => Ok(ngt!(v, u64, f64)),
             Value::I8(v) => Ok(f64::from(v)),
             Value::I16(v) => Ok(f64::from(v)),
             Value::I32(v) => Ok(f64::from(v)),
-            Value::I64(v) => Ok(ngt!(v, i64)),
+            Value::I64(v) => Ok(ngt_nlt!(v, i64, f64)),
+            Value::F32(v) => Ok(f64::from(v)),
+            Value::F64(v) => Ok(v),
             Value::String(v) => Ok(v.parse::<f64>()?),
             _ => Err(Error::invalid_data(ERR_INVALID_VALUE)),
         }
@@ -1122,7 +920,7 @@ impl TryFrom<Value> for f64 {
 
 impl TryFrom<Value> for Option<std::time::Duration> {
     type Error = Error;
-    #[inline]
+
     fn try_from(v: Value) -> EResult<Option<std::time::Duration>> {
         let t: f64 = v.try_into()?;
         if t > 0.0 {
@@ -1135,7 +933,7 @@ impl TryFrom<Value> for Option<std::time::Duration> {
 
 impl TryFrom<Value> for String {
     type Error = Error;
-    #[inline]
+
     fn try_from(v: Value) -> EResult<String> {
         match v {
             Value::Option(Some(s)) => Ok((*s).try_into()?),
@@ -1147,7 +945,7 @@ impl TryFrom<Value> for String {
 
 impl TryFrom<&Value> for String {
     type Error = Error;
-    #[inline]
+
     fn try_from(v: &Value) -> EResult<String> {
         match v {
             Value::Option(Some(s)) => Ok(s.as_ref().try_into()?),
@@ -1159,7 +957,7 @@ impl TryFrom<&Value> for String {
 
 impl<'a> TryFrom<&'a Value> for &'a str {
     type Error = Error;
-    #[inline]
+
     fn try_from(v: &'a Value) -> EResult<&'a str> {
         match v {
             Value::Option(Some(s)) => Ok(s.as_ref().try_into()?),
@@ -1171,7 +969,7 @@ impl<'a> TryFrom<&'a Value> for &'a str {
 
 impl TryFrom<Value> for Option<String> {
     type Error = Error;
-    #[inline]
+
     fn try_from(v: Value) -> EResult<Option<String>> {
         let s = match v {
             Value::Option(v) => match v {
@@ -1190,7 +988,7 @@ impl TryFrom<Value> for Option<String> {
 
 impl TryFrom<Value> for std::time::Duration {
     type Error = Error;
-    #[inline]
+
     fn try_from(v: Value) -> EResult<std::time::Duration> {
         Ok(std::time::Duration::from_secs_f64(v.try_into()?))
     }
@@ -1198,7 +996,7 @@ impl TryFrom<Value> for std::time::Duration {
 
 impl TryFrom<Value> for Vec<Value> {
     type Error = Error;
-    #[inline]
+
     fn try_from(value: Value) -> EResult<Vec<Value>> {
         match value {
             Value::Seq(vec) => Ok(vec),
@@ -1210,7 +1008,7 @@ impl TryFrom<Value> for Vec<Value> {
 
 impl<S: BuildHasher + Default> TryFrom<Value> for HashSet<Value, S> {
     type Error = Error;
-    #[inline]
+
     fn try_from(value: Value) -> EResult<HashSet<Value, S>> {
         match value {
             Value::Seq(vec) => Ok(HashSet::from_iter(vec)),
@@ -1221,7 +1019,6 @@ impl<S: BuildHasher + Default> TryFrom<Value> for HashSet<Value, S> {
 }
 
 impl From<HashSet<ipnetwork::IpNetwork>> for Value {
-    #[inline]
     fn from(v: HashSet<ipnetwork::IpNetwork>) -> Value {
         to_value(v).unwrap()
     }
@@ -1229,7 +1026,7 @@ impl From<HashSet<ipnetwork::IpNetwork>> for Value {
 
 impl<S: BuildHasher + Default> TryFrom<Value> for HashSet<ipnetwork::IpNetwork, S> {
     type Error = Error;
-    #[inline]
+
     fn try_from(value: Value) -> EResult<HashSet<ipnetwork::IpNetwork, S>> {
         match value {
             Value::Seq(vec) => {
@@ -1253,7 +1050,7 @@ impl<S: BuildHasher + Default> TryFrom<Value> for HashSet<ipnetwork::IpNetwork,
 
 impl TryFrom<Value> for Vec<String> {
     type Error = Error;
-    #[inline]
+
     fn try_from(value: Value) -> EResult<Vec<String>> {
         match value {
             Value::Seq(vec) => {
@@ -1271,7 +1068,7 @@ impl TryFrom<Value> for Vec<String> {
 
 impl TryFrom<&Value> for Vec<String> {
     type Error = Error;
-    #[inline]
+
     fn try_from(value: &Value) -> EResult<Vec<String>> {
         match value {
             Value::Seq(vec) => {
@@ -1289,7 +1086,7 @@ impl TryFrom<&Value> for Vec<String> {
 
 impl<'a> TryFrom<&'a Value> for Vec<&'a str> {
     type Error = Error;
-    #[inline]
+
     fn try_from(value: &'a Value) -> EResult<Vec<&'a str>> {
         match value {
             Value::Seq(vec) => {
@@ -1307,7 +1104,7 @@ impl<'a> TryFrom<&'a Value> for Vec<&'a str> {
 
 impl TryFrom<Value> for bool {
     type Error = Error;
-    #[inline]
+
     fn try_from(value: Value) -> EResult<bool> {
         match value {
             Value::Bool(v) => Ok(v),
@@ -1339,70 +1136,60 @@ impl TryFrom<Value> for bool {
 }
 
 impl From<&str> for Value {
-    #[inline]
     fn from(s: &str) -> Value {
         Value::String(s.to_owned())
     }
 }
 
 impl From<&String> for Value {
-    #[inline]
     fn from(s: &String) -> Value {
         Value::String(s.clone())
     }
 }
 
 impl From<Vec<Value>> for Value {
-    #[inline]
     fn from(v: Vec<Value>) -> Value {
         Value::Seq(v)
     }
 }
 
 impl From<HashSet<Value>> for Value {
-    #[inline]
     fn from(v: HashSet<Value>) -> Value {
         Value::Seq(Vec::from_iter(v))
     }
 }
 
 impl From<Vec<String>> for Value {
-    #[inline]
     fn from(v: Vec<String>) -> Value {
         Value::Seq(v.iter().map(Into::into).collect::<Vec<Value>>())
     }
 }
 
 impl From<BTreeMap<Value, Value>> for Value {
-    #[inline]
     fn from(v: BTreeMap<Value, Value>) -> Value {
         Value::Map(v)
     }
 }
 
 impl From<std::time::Duration> for Value {
-    #[inline]
     fn from(v: std::time::Duration) -> Value {
         v.as_secs_f64().into()
     }
 }
 
 impl From<Option<std::time::Duration>> for Value {
-    #[inline]
     fn from(v: Option<std::time::Duration>) -> Value {
         v.map_or(Value::Unit, |d| d.as_secs_f64().into())
     }
 }
 
 impl From<Option<f64>> for Value {
-    #[inline]
     fn from(v: Option<f64>) -> Value {
         v.map_or(Value::Unit, Value::F64)
     }
 }
 
 impl From<Option<String>> for Value {
-    #[inline]
     fn from(v: Option<String>) -> Value {
         v.map_or(Value::Unit, Into::into)
     }
